==> evolution-3.2.4.zip: evolution-3.2.4/assets/plugins/updater/lang/uk.php <==
<?php
// ---------------------------------------------------------------
// :: Updater
// ----------------------------------------------------------------
//
//
//
// ----------------------------------------------------------------
// :: Copyright & Licencing
// ----------------------------------------------------------------
//
//   GNU General Public License (GPL - http://www.gnu.org/copyleft/gpl.html)
//

$_lang['pluginname'] = 'Updater';
$_lang['system_update'] = 'Оновлення системи';
$_lang['are_you_sure_update'] = 'Ви впевнені, що хочете запустити оновлення системи?';
$_lang["cms_outdated_msg"] = 'Система управління контентом застаріла. Для оновлення звертайтеся до розробників сайту. Поточна версія';
$_lang['bkp_before_msg'] = 'Ми настійно рекомендуємо зробити резервну копію перед оновленням системи, оновлення виконується на ваш страх і ризик!!';
$_lang['updateButton_txt'] = 'Оновлення до версії';
$_lang['updateButtonCommit_txt'] = 'Оновіть цей комміт';
$_lang['table_commitdate'] = 'Дата фіксації';
$_lang['table_titleauthor'] = 'Назва (автор)';
//Error Messages
$_lang['error_curl'] = 'Вам потрібно ввімкнути функцію CURL у PHP';
$_lang['error_zip'] = 'Необхідно включити ZIP в PHP';
$_lang['error_openssl'] = 'Вам потрібно ввімкнути функцію OpenSSL у PHP';
$_lang['error_overwrite'] = 'Файли Evolution CMS недоступні для перезапису';
$_lang['error_failedtogetfeed'] = 'Не вдалося отримати канал';

$_lang['artisan_update'] = 'Для оновлення запустіть консольну команду з <b>core</b> теки: <b>php artisan make:site update</b>';

==> evolution-3.2.6.zip: evolution-3.2.6/assets/plugins/updater/lang/uk.php <==
<?php
// ---------------------------------------------------------------
// :: Updater
// ----------------------------------------------------------------
//
//
//
// ----------------------------------------------------------------
// :: Copyright & Licencing
// ----------------------------------------------------------------
//
//   GNU General Public License (GPL - http://www.gnu.org/copyleft/gpl.html)
//

$_lang['pluginname'] = 'Updater';
$_lang['system_update'] = 'Оновлення системи';
$_lang['are_you_sure_update'] = 'Ви впевнені, що хочете запустити оновлення системи?';
$_lang["cms_outdated_msg"] = 'Система управління контентом застаріла. Для оновлення звертайтеся до розробників сайту. Поточна версія';
$_lang['bkp_before_msg'] = 'Ми настійно рекомендуємо зробити резервну копію перед оновленням системи, оновлення виконується на ваш страх і ризик!!';
$_lang['updateButton_txt'] = 'Оновлення до версії';
$_lang['updateButtonCommit_txt'] = 'Оновіть цей комміт';
$_lang['table_commitdate'] = 'Дата фіксації';
$_lang['table_titleauthor'] = 'Назва (автор)';
//Error Messages
$_lang['error_curl'] = 'Вам потрібно ввімкнути функцію CURL у PHP';
$_lang['error_zip'] = 'Необхідно включити ZIP в PHP';
$_lang['error_openssl'] = 'Вам потрібно ввімкнути функцію OpenSSL у PHP';
$_lang['error_overwrite'] = 'Файли Evolution CMS недоступні для перезапису';
$_lang['error_failedtogetfeed'] = 'Не вдалося отримати канал';

$_lang['artisan_update'] = 'Для оновлення запустіть консольну команду з <b>core</b> теки: <b>php artisan make:site update</b>';
$_lang["help_donate_msg"] = 'Купуйте каву розробникам Evolution CMS на <a href="https://ko-fi.com/evolutioncms" target="_blank">ko-fi.com/evolutioncms ☕</a>. Станьте прихильником Evolution CMS ❤️ сьогодні!';
